@@ -14,6 +14,7 @@ import logging
 import os
 import platform
 import socket
+import tarfile
 import uuid
 from waveletai import envs
 from waveletai.model import Model
@@ -1084,8 +1085,12 @@ class HostedBackend(Backend):
             self._url_download((feature_path, destination, file_name))
             zip_path = destination + '/' + file_name
             if unzip is True:
-                with zipfile.ZipFile(zip_path, 'r') as zip_ref:
-                    zip_ref.extractall(destination)
+                if '.zip' in zip_path:
+                    with zipfile.ZipFile(zip_path, 'r') as zip_ref:
+                        zip_ref.extractall(destination)
+                else:
+                    with tarfile.open(zip_path, 'r') as tar_ref:
+                        tar_ref.extractall(destination)
                 os.remove(zip_path)
         except Exception as e:
             raise e
